/**
 *
 * Copyright (C) 2010 Cloud Conscious, LLC. <info@cloudconscious.com>
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.jclouds.azure.storage.queue.domain;

import java.net.URI;

/**
 * 
 * @author Adrian Cole
 * 
 */
public class QueueMetadata implements Comparable<QueueMetadata> {
   private final String name;
   private final URI url;

   public QueueMetadata(String name, URI url) {
      this.name = name;
      this.url = url;
   }

   @Override
   public String toString() {
      return "QueueMetadata [name=" + name + ", url=" + url + "]";
   }

   @Override
   public int hashCode() {
      final int prime = 31;
      int result = 1;
      result = prime * result + ((name == null) ? 0 : name.hashCode());
      result = prime * result + ((url == null) ? 0 : url.hashCode());
      return result;
   }

   @Override
   public boolean equals(Object obj) {
      if (this == obj)
         return true;
      if (obj == null)
         return false;
      if (getClass() != obj.getClass())
         return false;
      QueueMetadata other = (QueueMetadata) obj;
      if (name == null) {
         if (other.name != null)
            return false;
      } else if (!name.equals(other.name))
         return false;
      if (url == null) {
         if (other.url != null)
            return false;
      } else if (!url.equals(other.url))
         return false;
      return true;
   }

   public String getName() {
      return name;
   }

   public URI getUrl() {
      return url;
   }

   public int compareTo(QueueMetadata o) {
      return (this == o) ? 0 : getName().compareTo(o.getName());
   }
}
